#!/usr/bin/env python
# -*- coding: utf-8 -*-

__title__ = 'vint'
__version__ = '0.1.1'
__author__ = 'Tyr Chen'
__email__ = 'tyr.chen@gmail.com'
__license__ = 'MIT'
__copyright__ = 'Copyright 2013 Tyr Chen'


